.. _activate-the-environment:
Activate the environment
************************

Windows
=======

1. Open the Miniforge Prompt

2. Activate the environment with the following command:

.. code-block:: bash

   conda activate carde-env

3. change to the directory where the images are stored

.. code-block:: bash

   P:
   cd path\to\images


Linux
=====

1. Activate the environment with the following command (in a terminal):

.. code-block:: bash

   source carde-env/bin/activate

2. change to the directory where the images are stored

.. code-block:: bash

   cd path/to/images
